@@ -1,19 +1,23 @@
 import io
 import json
 import math
-import os
+import uuid
 
 import requests
 from requests import Response
 
 
 class DirectusApi:
-
     def __init__(self, username, password, endpoint):
         self.username = username
         self.password = password
         self.endpoint = endpoint
         self.access_token, self.refresh_token = self.__get_jwt_token()
+        self.request_headers = {
+            'Authorization': 'Bearer ' + self.access_token,
+            'Content-Type': 'application/json',
+            'Accept': 'application/json'
+        }
 
     def __get_jwt_token(self) -> tuple:
         """
@@ -31,31 +35,32 @@ class DirectusApi:
         Make a GET-Request to /items/<collection_name> and return the response as JSON.
         """
         url = self.endpoint + '/items/' + collection
-        headers = {
-            'Authorization': 'Bearer ' + self.access_token,
-            'Content-Type': 'application/json',
-            'Accept': 'application/json'
-        }
-        response = requests.get(url, headers=headers)
+        response = requests.get(url, headers=self.request_headers)
         return response.json()
 
     def create_items(self, items: list, collection: str) -> Response:
         """
+        Create multiple items in a collection.
         Make a POST-Request to /items/<collection_name> and return the response as JSON.
         """
         url = self.endpoint + '/items/' + collection
-        headers = {
-            'Authorization': 'Bearer ' + self.access_token,
-            'Content-Type': 'application/json',
-            'Accept': 'application/json'
-        }
-        response = requests.post(url, json=items, headers=headers)
+        response = requests.post(url, json=items, headers=self.request_headers)
+        return response
+
+    def updates_items(self, items: list, collection: str) -> Response:
+        """
+        Update multiple items in a collection. The items must have an id (primary key) field.
+        Make a PATCH-Request to /items/<collection_name> and return the response as JSON.
+        """
+        url = self.endpoint + '/items/' + collection
+        response = requests.patch(url, json=items, headers=self.request_headers)
         return response
 
     def import_items_by_json_file(self, filename: str, collection: str) -> Response:
         files = {'file': (filename, open(filename, 'rb'), 'application/json')}
         url = self.endpoint + '/utils/import/' + collection
         headers = {
+            # Do not add Content-Type header here. Request lib will handle by itself for files.
             'Authorization': 'Bearer ' + self.access_token,
             'Accept': 'application/json'
         }
@@ -65,7 +70,7 @@ class DirectusApi:
 
     def import_items_by_data(self, data: list, collection: str) -> Response:
         file = io.BytesIO(json.dumps(data).encode('utf-8'))
-        files = {'file': ('example.json', file, 'application/json')}
+        files = {'file': (str(uuid.uuid4()) + '.json', file, 'application/json')}
         url = self.endpoint + '/utils/import/' + collection
         headers = {
             'Authorization': 'Bearer ' + self.access_token,
@@ -75,33 +80,41 @@ class DirectusApi:
 
         return response
 
-    def get_items_from_collection(self, collection: str, limit: int, page_size=25000):
+    def get_items_from_collection(self, collection: str, limit: int = None, page_size: int = 25000,
+                                  filter_dict: dict = None):
         """
         Get all items from a collection and return them as list.
+        :param filter_dict: A dict with the filter parameters.
+                            See https://docs.directus.io/reference/introduction.html#search-http-method
         :param collection: The name of the collection.
         :param limit: The limit of items to return. If None all items will be returned.
         :param page_size: The number of items to return per request. Set this value depending of the RAM of your machine.
         :return: A list of items. Each item is a dictionary with the fields of the collection.
         """
 
-        def __helper(page_size: int, page: int):
-            url = self.endpoint + '/items/' + collection
+        def __helper(page_size: int, page: int, filter_dict: dict = None):
+            if filter_dict is not None:
+                # Build url with query-parameters (e.g. ?filter[match_id][_eq]=wzi6xmt37)
+                url_query = '?filter' + ''.join(
+                    [f'[{k}][{k2}]={v2}' for k, v in filter_dict.items() for k2, v2 in v.items()])
+            else:
+                url_query = ''
+
+            url = self.endpoint + '/items/' + collection + url_query
             headers = {
                 'Authorization': 'Bearer ' + self.access_token,
                 'Content-Type': 'application/json',
                 'Accept': 'application/json'
             }
-            return requests.get(url, headers=headers, params={
-                'limit': page_size,
-                'meta': '*',
-                'page': page
-            })
+            return requests.get(
+                url, headers=headers,
+                params={'limit': page_size, 'meta': '*', 'page': page})
 
         # Set page_size to limit if limit is smaller than page_size
         if limit < page_size:
             page_size = limit
 
-        response = __helper(page_size=page_size, page=1)
+        response = __helper(page_size=page_size, page=1, filter_dict=filter_dict)
         items = response.json()['data']
         total = response.json()['meta']['filter_count']
 
@@ -115,3 +128,33 @@ class DirectusApi:
             items.extend(response.json()['data'])
 
         return items[:limit]
+
+    def delete_item_by_id(self, collection: str, id: int) -> Response:
+        """
+        Delete an item by id.
+        Make a DELETE-Request to /items/<collection_name>/<id> and return the response as JSON.
+        """
+        url = self.endpoint + '/items/' + collection + '/' + str(id)
+        headers = {
+            'Authorization': 'Bearer ' + self.access_token,
+            'Content-Type': 'application/json',
+            'Accept': 'application/json'
+        }
+        response = requests.delete(url, headers=headers)
+        return response
+
+    def delete_all_items_from_collection(self, collection: str):
+        """
+        Delete all items from a collection.
+        Make a DELETE-Request to /items/<collection_name> and return the response as JSON.
+        Returns status_code 204 on success.
+        """
+        url = self.endpoint + '/items/' + collection
+        headers = {
+            'Authorization': 'Bearer ' + self.access_token,
+            'Content-Type': 'application/json',
+            'Accept': 'application/json'
+        }
+        response = requests.delete(url, headers=headers, json={'query': {'limit': -1}})
+
+        return response
